<?php

/**
 * Check to see if the logo file actually exists. If not, remove the path.
 */
if (!is_file(str_replace(base_path(), '', $vars['logo']))) {
  $vars['logo'] = NULL;
}

/**
 * Check for stylesheets to be placed at the top of the stack or conditional
 * Internet Explorer styles in the .info file and add them to the $styles
 * variable.
 */
$top_styles = array();
$ie_styles = array();

/**
 * If there is more than one active theme, check all base themes for
 * stylesheets.
 */
if (count($themes_active) > 1) {
  foreach ($base_theme_info as $name => $info) {
    if (isset($info->info['top stylesheets'])) {
      $top_styles[$name] = $info->info['top stylesheets'];
    }
    if (isset($info->info['ie stylesheets'])) {
      $ie_styles[$name] = $info->info['ie stylesheets'];
    }
  }
}

/**
 * Check the current theme for stylesheets.
 */
if (isset($theme_info->info['top stylesheets'])) {
  $top_styles[$theme_info->name] = $theme_info->info['top stylesheets'];
}
if (isset($theme_info->info['ie stylesheets'])) {
  $ie_styles[$theme_info->name] = $theme_info->info['ie stylesheets'];
}

/**
 * If there is at least one entry in the $top_styles array, process it.
 */
if (count($top_styles) >= 1) {
  // Format the array into a format readable by drupal_get_css().
  $vars['top_css'] = array();
  foreach ($top_styles as $name => $theme_styles) {
    $path = drupal_get_path('theme', $name);
    foreach ($theme_styles as $media => $styles) {
      foreach ($styles as $style){
        $vars['top_css'][$media]['featured'][$path . '/' . $style] = TRUE;
      }
      // Add the new styles to the top of the $vars['css'] array.
      array_unshift($vars['css'][$media], $vars['top_css'][$media]['featured']);
    }
  }
  // Run $vars['css'] through drupal_get_css and replace the $styles variable.
  $vars['styles'] = drupal_get_css($vars['css']);
}

/**
 * If there is at least one entry in the $ie_styles array, process it.
 */
if (count($ie_styles) >= 1) {
  // Format the array into a format readable by drupal_get_css().
  $vars['ie_css'] = array();
  foreach ($ie_styles as $name => $theme_styles) {
    $path = drupal_get_path('theme', $name);
    foreach ($theme_styles as $version => $media) {
      foreach ($media as $type => $styles) {
        foreach ($styles as $style) {
          $vars['ie_css'][$version][$type]['theme'][$path . '/' . $style] = TRUE;
        }
      }
    }
  }
  // Append the stylesheets to $styles, grouped by IE conditional.
  foreach ($vars['ie_css'] as $version => $styles) {
    $vars['styles'] .= '<!--[if ' . $version . ']>' . "\n" . drupal_get_css($styles) . '<![endif]-->' . "\n";
  }
}

$vars['page']->studio_attributes['html']['#attributes']['xmlns'] = 'http://www.w3.org/1999/xhtml';
$vars['page']->studio_attributes['html']['#attributes']['xml:lang'] = $vars['language']->language;
$vars['page']->studio_attributes['html']['#attributes']['lang'] = $vars['language']->language;
$vars['page']->studio_attributes['html']['#attributes']['dir'] = $vars['language']->dir;

$vars['page']->studio_attributes['home_link']['#attributes']['href'] = $vars['front_page'];

if ($vars['logo']) {
  $vars['page']->studio_attributes['logo']['#attributes']['src'] = $vars['logo'];
}

$elements = array('site_name',
                  'site_slogan',
                  'search_box',
                  'breadcrumb',
                  'mission',
                  'title',
                  'tabs',
                  'content',
                  'primary_links',
                  'secondary_links');

foreach ($elements as $element) {
  if ($vars[$element] && !isset($vars['page']->studio_attributes[$element])) {
    $vars['page']->studio_attributes[$element]['#attributes'] = array();
  }
}

$wrappers = array('body',
                  'page',
                  'container',
                  'content_column');

if ($vars['site_name'] || $vars['logo'] || $vars['site_slogan'] || $vars['header']) {
  $wrappers[] = 'header';
}

if ($vars['primary_links'] || $vars['secondary_links']) {
  $wrappers[] = 'navigation';
}

if ($vars['feed_icons'] || $vars['footer_message'] || $vars['footer']) {
  $wrappers[] = 'footer';
}

foreach ($wrappers as $wrapper) {
  if (!isset($vars['page']->studio_attributes[$wrapper])) {
    $vars['page']->studio_attributes[$wrapper]['#attributes'] = array();
  }
}
