<?php

/**
 * Implementation of hook_theme().
 *
 * @return
 */
function canvas_theme() {
  return array(
    'id_safe' => array(
      'arguments' => array('string'),
      'file' => 'functions/theme-custom.inc',
    ),
    'process_attributes' => array(
      'arguments' => array('attributes' => array(),
                           'merge' => NULL),
      'file' => 'functions/theme-custom.inc',
    ),
    'region' => array(
      'arguments' => array(
        'region' => NULL,
      ),
      'pattern' => 'region_',
      'path' => drupal_get_path('theme', 'canvas') . '/templates/custom',
      'template' => 'region',
    ),
    'render_attributes' => array(
      'arguments' => array('attributes'),
      'file' => 'functions/theme-custom.inc',
    ),
  );
}

/**
 * Offload all theme overrides to a separate file to make template.php more
 * manageable.
 */
include_once('functions/theme-overrides.inc');

/**
 * Implementation of hook_preprocess()
 *
 * This function checks to see if a hook has a preprocess file associated with
 * it, and if so, loads it.
 *
 * @param $vars
 * @param $hook
 * @return Array
 */
function canvas_preprocess(&$vars, $hook) {
  // Collect all information for the active theme.
  $themes_active = array();
  global $theme_info;

  // If there is a base theme, collect the names of all themes that may have
  // data files to load.
  if (isset($theme_info->base_theme)) {
    global $base_theme_info;
    foreach ($base_theme_info as $base){
      $themes_active[] = drupal_get_path('theme', $base->name);
    }
  }

  // Add the active theme to the list of themes that may have data files.
  $themes_active[] = drupal_get_path('theme', $theme_info->name);

  // Collect the hooks to be processed. Some modules (like Views have parent
  // template and preprocess files for the hooks.
  $hooks = array();
  $subhook_position = strpos($hook, '__');

  if ($subhook_position !== FALSE) {
    $hook_pieces = explode('__', $hook);
    $hooks[] = array_shift($hook_pieces);
    foreach ($hook_pieces as $piece) {
      $last_hook = count($hooks) - 1;
      $hooks[] = $hooks[$last_hook] . '__' . $piece;
    }
  }

  $hooks[] = $hook;

  // Declare the raw attributes array for a hook if it does not already exist.
  if (isset($vars[$hooks[0]]) && is_string($vars[$hooks[0]])) {
    $vars['content'] = $vars[$hooks[0]];
    $vars[$hooks[0]] = new stdClass;
  }

  if (!isset($vars[$hooks[0]]->studio_attributes)) {
    $vars[$hooks[0]]->studio_attributes = array();
  }

  // If not already set, declare the array for the rendered attributes.
  if (!isset($vars['attributes'])) {
    $vars['attributes'] = array($hook => array('#attributes' => array(), '#value' => ''));
  }

  // Check all active themes for preprocess files that will need to be loaded. A
  // track record of whether a file for a theme exists to optimize disc
  // performance.
  static $preprocess_includes = array();

  foreach ($themes_active as $name) {
    foreach ($hooks as $hook) {
      $id = str_replace('_', '-', $hook);
      if (!isset($preprocess_includes[$name][$hook]) && !is_file($name . '/preprocess/preprocess-' . $id . '.inc')) {
        $preprocess_includes[$name][$hook] = NULL;
      }
      elseif (!isset($preprocess_includes[$name][$hook]) && is_file($name . '/preprocess/preprocess-' . $id . '.inc')) {
        $preprocess_includes[$name][$hook] = $name . '/preprocess/preprocess-' . $id . '.inc';
        include($preprocess_includes[$name][$hook]);
      }
      elseif ($preprocess_includes[$name][$hook] != NULL) {
        include($preprocess_includes[$name][$hook]);
      }
    }
  }

  // Merge in required attributes and then process all of a hooks attributes and
  // format them for output in the template.
  $vars['attributes'] = theme('process_attributes', $vars['attributes'], $vars[$hooks[0]]->studio_attributes);
}
