<?php

/**
 * @file forum-list.tpl.php
 * Default theme implementation to display a list of forums and containers.
 *
 * Available variables:
 * - $forums: An array of forums and containers to display. It is keyed to the
 *   numeric id's of all child forums and containers.
 * - $forum_id: Forum id for the current forum. Parent to all items within
 *   the $forums array.
 *
 * Each $forum in $forums contains:
 * - $forum->is_container: Is TRUE if the forum can contain other forums. Is
 *   FALSE if the forum can contain only topics.
 * - $forum->depth: How deep the forum is in the current hierarchy.
 * - $forum->zebra: 'even' or 'odd' string used for row class.
 * - $forum->name: The name of the forum.
 * - $forum->link: The URL to link to this forum.
 * - $forum->description: The description of this forum.
 * - $forum->new_topics: True if the forum contains unread posts.
 * - $forum->new_url: A URL to the forum's unread posts.
 * - $forum->new_text: Text for the above URL which tells how many new posts.
 * - $forum->old_topics: A count of posts that have already been read.
 * - $forum->num_posts: The total number of posts in the forum.
 * - $forum->last_reply: Text representing the last time a forum was posted or
 *   commented in.
 *
 * @see template_preprocess_forum_list()
 * @see theme_forum_list()
 */
?>
<table<?php print $attributes['forum_list']['#value']; ?>>
  <thead>
    <tr<?php print $attributes['head']['#value']; ?>>
      <th<?php print $attributes['head']['forum']['#value']; ?>><?php print t('Forum'); ?></th>
      <th<?php print $attributes['head']['topics']['#value']; ?>><?php print t('Topics');?></th>
      <th<?php print $attributes['head']['posts']['#value']; ?>><?php print t('Posts'); ?></th>
      <th<?php print $attributes['head']['last_post']['#value']; ?>><?php print t('Last post'); ?></th>
    </tr>
  </thead>
  <tbody>
  <?php foreach ($forums as $child_id => $forum): ?>
    <tr<?php print $attributes['forums'][$forum->studio_id]['#value']; ?>>
      <td<?php print $attributes['forums'][$forum->studio_id]['forum']['#value']; ?>>
        <?php /* Enclose the contents of this cell with X divs, where X is the
               * depth this forum resides at. This will allow us to use CSS
               * left-margin for indenting.
               */ ?>
        <?php print str_repeat('<div' . $attributes['forums'][$forum->studio_id]['indent']['#value'] . '>' . "\n", $forum->depth); ?>
          <div<?php print $attributes['forums'][$forum->studio_id]['name']['#value']; ?>>
            <a<?php print $attributes['forums'][$forum->studio_id]['name']['link']['#value']; ?>><?php print $forum->name; ?></a>
          </div>
          <?php if ($forum->description): ?>
          <div<?php print $attributes['forums'][$forum->studio_id]['description']['#value']; ?>>
            <?php print $forum->description; ?>
          </div>
          <?php endif; ?>
        <?php print str_repeat('</div>', $forum->depth); ?>
      </td>
      <?php if (!$forum->is_container): ?>
      <td<?php print $attributes['forums'][$forum->studio_id]['topics']['#value']; ?>>
        <?php print $forum->num_topics ?>
        <?php if ($forum->new_topics): ?>
        <div<?php print $attributes['forums'][$forum->studio_id]['new_topics']['#value']; ?>>
          <a href="<?php print $forum->new_url; ?>"><?php print $forum->new_text; ?></a>
        </div>
        <?php endif; ?>
      </td>
      <td<?php print $attributes['forums'][$forum->studio_id]['posts']['#value']; ?>><?php print $forum->num_posts ?></td>
      <td<?php print $attributes['forums'][$forum->studio_id]['last_reply']['#value']; ?>><?php print $forum->last_reply ?></td>
      <?php endif; ?>
    </tr>
  <?php endforeach; ?>
  </tbody>
</table>
